import { BaseError } from "make-error";
/**
 * Invalid environment error.
 */
export declare class InvalidEnvError<T extends PropertyKey> extends BaseError {
    missing: T[];
    invalid: Array<[T, any]>;
    constructor(missing: T[], invalid: Array<[T, any]>);
}
/**
 * Valid schema object.
 */
export interface Schema {
    [key: string]: (value: string) => any;
}
/**
 * Valid source object.
 */
export declare type Source<T extends PropertyKey> = Partial<Record<T, string>>;
/**
 * Derive the environment from a simple schema.
 */
export declare type Env<T extends Schema> = {
    [K in keyof T]: Exclude<ReturnType<T[K]>, undefined>;
};
/**
 * Tiny environment variable helper.
 */
export declare function envobj<T extends Schema>(schema: T, source: Source<keyof T>, ...sources: Source<keyof T>[]): Env<T>;
/**
 * Parse string variable.
 */
export declare const string: (input: string) => string;
/**
 * Parse boolean variable.
 */
export declare const boolean: (input: string) => boolean | undefined;
/**
 * Parse numeric variable.
 */
export declare const number: (input: string) => number | undefined;
/**
 * Parse integer variable.
 */
export declare const integer: (input: string) => number | undefined;
