"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("./index");
describe("envobj", () => {
    it("should parse env", () => {
        const env = index_1.envobj({ STRING: index_1.string, BOOLEAN: index_1.boolean, NUMBER: index_1.number }, { STRING: "foobar" }, { BOOLEAN: "true" }, { NUMBER: "123" });
        expect(env).toEqual({ STRING: "foobar", BOOLEAN: true, NUMBER: 123 });
    });
    it("should error on missing keys", () => {
        expect(() => index_1.envobj({ MISSING: index_1.string }, {})).toThrowError(index_1.InvalidEnvError);
    });
    it("should error on invalid keys", () => {
        expect(() => index_1.envobj({ INVALID: index_1.number }, { INVALID: "test" })).toThrowError(index_1.InvalidEnvError);
    });
    describe("string", () => {
        it("should return strings", () => {
            expect(index_1.string("123")).toEqual("123");
        });
    });
    describe("boolean", () => {
        it("should return booleans", () => {
            expect(index_1.boolean("true")).toEqual(true);
            expect(index_1.boolean("TRUE")).toEqual(true);
            expect(index_1.boolean("false")).toEqual(false);
            expect(index_1.boolean("FALSE")).toEqual(false);
            expect(index_1.boolean("invalid")).toEqual(undefined);
        });
    });
    describe("number", () => {
        it("should return numbers", () => {
            expect(index_1.number("123")).toEqual(123);
            expect(index_1.number("123.45")).toEqual(123.45);
            expect(index_1.number("invalid")).toEqual(undefined);
        });
    });
    describe("integer", () => {
        it("should return integers", () => {
            expect(index_1.integer("123")).toEqual(123);
            expect(index_1.integer("123.45")).toEqual(undefined);
            expect(index_1.integer("invalid")).toEqual(undefined);
        });
    });
    describe("localenv integration", () => {
        beforeAll(() => {
            require("localenv");
        });
        it("should load from `.env`", () => {
            const env = index_1.envobj({ LOCALENV_TEST: index_1.boolean }, process.env);
            expect(env).toEqual({ LOCALENV_TEST: true });
        });
    });
});
//# sourceMappingURL=index.spec.js.map